TRANSCAN.DOC

36.5 KB 96765662b7e3f934…
ANSI art: TRANSCAN.DOC
B






                                    TranScan v2.30
                                 by Craig E. Dunstan

                                 Copyright 1991-1992
                                 ALL RIGHTS RESERVED

        Short Description:
        -----------------

        TranScan v2.30 -- Use in SCANFILE.BAT with Wildcat v3.+

        Long Description:
        ----------------

        TranScan is a Compressed file SCANNER and CONVERTER.  It  UnCompresses
        files in the  ARC, ARJ,  DWC, HYP,  ICE, LZH,  PAK, SDN,  ZIP, or  ZOO
        formats.  It then  uses ViruScan by McAfee  & Associates to check  for
        hidden Viruses.  It will then Compress the files using your choice  of
        Compression programs (all the above  are supported), and it will  also
        add your ZIP comment.

        TranScan updates the  Wildcat 3+  File Database and  all related  keys
        effortlessly.  You can even use it  to convert the files of an  entire
        Hard Drive including all Sub-Directories!

        It detects DESC.SDI and FILE_ID.DIZ  description files and copies  the
        description to the Wildcat Database updating all associated KEY  WORDS
        as well.

        Total Cost is only $15.

        Features:
        --------
           
          *  UnCompresses almost ALL types of files! 
          *  Scans for Viruses using ViruScan by McFee & Associates! 
          *  Compresses using your choice of programs! 
          *  Compresses GIF, DOC, TXT files and more! 
          *  Processes Single Directories, Sub Directories or entire Disks! 
          *  Updates Wildcat 3+ effortlessly! 
          *  Imports Descriptions from DESC.SDI and FILE_ID.DIZ files. 
          *  COM Output to on-line callers! Ports 1-8 & up to 115,000 baud! 
          *  NETWORK Support for Novell, 3-COM, Banyan Vines, PCMOS 386,
             Net/OS (CBIS Net), LANtastic, and any networks that truly support
             DOS SHARE. 
          *  Easy Setup! Command line driven! 
          *  No EXPIRE keys to download! 
          *  Low Cost: $15  



        2/25/92                     TRANSCAN v2.30                      Page 2

                                  TABLE OF CONTENTS 

             Topic                                                  

        1.0  WHAT DO I NEED TO GET STARTED?                         

        2.0  WHAT OPTIONS ARE AVAILABLE?                            

        3.0  USE [esc] TO ABORT PROCESSING!                         

        4.0  WHAT HAPPENS WHEN A VIRUS IS DETECTED?                 

        5.0  EXIT ERRORLEVELS                                       

        6.0  COPYRIGHT                                              

        7.0  WARRANTY                                               

        8.0  REGISTRATION                                           

        9.0 WHAT ABOUT DESC.SDI & FILE_ID.DIZ FILES?

        10.0 DISTRIBUTION & DISTRIBUTORS                            

        11.0 TECHNICAL SUPPORT                                      

        12.0 ACKNOWLEDGEMENTS                                       

        13.0 BETA TEST TEAM                                         

        14.0 ERROR CODES OF EXTERNAL PROGRAMS                       

        15.0 COMMAND LINE OPTIONS USED IN EXTERNAL PROGRAMS         

             REGISTRATION FORM                                      























         



        2/25/92                     TRANSCAN v2.30                      Page 3

        1.0  WHAT DO I NEED TO GET STARTED? 
        ----------------------------------- 

        Required: 

          -  You must have a copy of TranScan located in a directory that is
             in your PATH statement. 

        Highly Desirable: 

          -  You should have the following files in a directory that is in
             your PATH statement: 

          Exe File     Version   Archive        Explanation
          --------     -------   -------        -----------
          SCAN.EXE     85        SCANV85.ARJ    ViruScan program by McFee &
                                                Associates
          ZC.EXE       2.00      ZC200.ARJ      Writes Zip Comments
          ARJ.EXE      2.20      ARJ220.EXE     Process *.arj files
          DWC.EXE      5.10      DWC-A510.EXE   Process *.dwc files
          LHA.EXE      2.12      LHA212.EXE     Process *.lzh files
          ICE.EXE      1.14      UnKnown        Process *.ice files (Ice is an
                                                earlier version of LHarc).
          PAK.EXE      2.51      PAK251.EXE     Process *.pak & *.sdn files
          PKPAK.EXE    3.61      PK361.EXE      Process *.arc files
          PKUNPAK.EXE  3.61      PK361.EXE      Process *.arc files
          PKZIP.EXE    1.10      PKZ110.EXE     Process *.zip files
          PKUNZIP.EXE  1.10      PKZ110.EXE     Process *.zip files
          ZOO.EXE      2.01      ZOO201.EXE     Process *.zoo files
          GIFLITE.EXE  1.22      GIFLITE.ARJ    Process *.gif files

        Wildcat 3+ SysOps:

          -  You should add the following command to your CONFIG.SYS file:
             SET WCNODEID=1
             This tells TranScan which Node is running TranScan during the
             SCANFILE.BAT process. 

          -  You should create a text file called SCANFILE.BAT and locate this
             in your WILDCAT! Home Directory (e.g. \WC30 ).  This file should
             contain the following line:
             TRANSCAN %1  

          -  You should add the following line to a nightly event bat file:
             TRANSCAN -F -CARJ -G
             This will change all files earlier TRANSCANed during the
             SCANFILE.BAT and convert them to ARJ (or your choice), and also
             compress all *.GIF files using GIFLITE. 

        Optional but desirable: 

          -  You may create a ZIP or ARJ comment file and name it TRANSCAN.CMT
             and place it in the same directory where you put TRANSCAN.EXE. 





         



        2/25/92                     TRANSCAN v2.30                      Page 4


          -  You may create a TRANSCAN.DEL file which is a list of all the
             files you want deleted from archives at time of ReCompression.
             This file should be placed in the same directory where you put
             TRANSCAN.EXE. 

          -  You may compress TRANSCAN.EXE by using the popular PKLITE.EXE
             program even though PKLite will probably warn you that it
             TRANSCAN.EXE may contain overlay files. 

        2.0  WHAT OPTIONS ARE AVAILABLE?
        --------------------------------

        There are a number of command line options available.  Some of them
        WILL NOT work during the SCANFILE.BAT process and this will be
        indicated next to the option.
         
        SCANFILE.BAT COMMAND LINE:
         
             TranScan %1 <optional switches>

        %1 is the filename supplied by Wildcat.  Optional switches include: 

        -A<maxAgeInDays>
        -B
        -L<logPathAndName>
        -T<K|C|Y|O><W>
        -Z<commentFilePathAndName> 

        ANY OTHER COMMAND LINE: 

             TranScan <fileName> <optional switches>
         
        Any existing filename may be used.  Dos wildcard keys "*" and "?" may
        also be used. 

        -A<maxAgeInDays>           AGE CHECK SWITCH        YES in SCANFILE.BAT
                  All files older than <maxAgeInDays> will be marked as
                  "FAILED" in the TRANSCAN.LOG  (The file will not be renamed
                  *.BAD).  You determine the Age criteria with the -T switch!
                  The example below disqualifies a file if the Youngest file
                  in the archive is older than two years (730 days).
                   
                  EXAMPLE: TranScan %1 -TY -A730
                   
                  Wildcat 3+ SysOps:
                  All files disqualified will be marked as "Scan Failed" in
                  the WildCat database.  TranScan will also write the
                  ScanFile.Bad file in the Node Work directory. 

        -B                        DISABLE COM OUTPUT       YES in SCANFILE.BAT
                  This disables the COM routines.  Things run as before but
                  with NO output to the online caller.  Some of the FASTER





         



        2/25/92                     TRANSCAN v2.30                      Page 5

                  boards have requested this switch because the processing of
                  TranScan is so fast! 

        -C<method>                COMPRESSION METHOD        NO in SCANFILE.BAT
                  ReCompress all files after SCANning using this method.
                  Valid methods include: ARC, ARJ, DWC, HYP, ICE, LZH, PAK,
                  ZIP, and ZOO.  If this switch is NOT used the file will be
                  UnCompressed, Scanned, Arj or Zip Commented, and the
                  filename will be written to a text file named TRANSCAN.LST
                  for later processing using the -F switch.
                   
                  EXAMPLE: TranScan *.* -Carj

        -D                      SELECTIVE SCAN SWITCH       NO in SCANFILE.BAT
                  This switch instructs TranScan to look for the file
                  TRANSCAN.DID in the directory it is to process.  This file
                  contains a list of all the files in that directory that
                  TranScan has already processed.  It will only process files
                  it does not find in the list and it adds all the files it
                  processes to the list.
                   
                  EXAMPLE: TranScan c:\Files\Area0001\*.* -Carj -D

         

        -E                       COMPRESS EVERYTHING        NO in SCANFILE.BAT
                  This switch instructs TranScan to convert EVERYTHING it
                  cannot UnCompress or GIFLite to your compression method of
                  choice.  I would recommend you use this carefully.
                   
                  EXAMPLE: TranScan *.txt -E -CARJ
                           TranScan *.doc -E -CARJ

        -F                       FILE LIST PROCESSING       NO in SCANFILE.BAT
                  This processes the files listed in the text file named
                  TRANSCAN.LST which will be located in the same directory as
                  TRANSCAN.EXE.  TRANSCAN.LST is a list of all the files
                  processed during the SCANFILE.BAT process or processed with
                  no -C<method> switch.
                   
                  EXAMPLE: TranScan -F -Carj

        -F<filePathAndName>      FILE LIST PROCESSING       NO in SCANFILE.BAT
                  This processes all the files that appear in this text file.
                  Be sure to include full path and name and do not put a space
                  between the switch and the filename.
                   
                  EXAMPLE: TranScan -Fc:\work\list.txt -Carj 

        -G                      PROCESS USING GIFLITE       NO in SCANFILE.BAT
                  Use GIFLite to compress *.GIF files.  TranScan compresses
                  GIF files even nested inside other Compressed files.
                  GIFLite can really compress those GIFs but I find it to be
                  extremely slow.  I would recommend using the -G , -M and -D




         



        2/25/92                     TRANSCAN v2.30                      Page 6

                  switches together.
                   
                  EXAMPLE: TranScan c:\gifFiles\*.GIF -G -M60 -D  

        -L<logPathAndName>         LOG FILE SWITCH         YES in SCANFILE.BAT
                  This switch defines which file you want your LOG entries
                  written to.  If this switch is not used TranScan creates a
                  LOG named TRANSCAN.LOG in the same directory where your
                  TRANSCAN.EXE is located.  Some SysOps use this feature to
                  write the SCANFILE.BAT processing to their ACTIVITY.001 log.
                   
                  EXAMPLE: TranScan %1 -L\WC30\ACTIVITY.001 

         

        -M<minutes>                 MINUTE SWITCH           NO in SCANFILE.BAT
                  This switch tells TranScan to only process for so many
                  minutes.  This is helpful if you want to compress those GIF
                  files using GIFLITE but you want to do it from 2am-3am every
                  night when the BBS isn't very busy.  Maybe you want to
                  convert from ZIP to ARJ but you want to do it one file at a
                  time between calls.  All this can be accomplished with the -
                  M switch.  (Note: It will not stop processing at the time
                  you set, rather it will not start processing a new file
                  after that time has expired)
                   
                  EXAMPLE: TranScan c:\gifFiles\*.GIF -G -D -M60
                     or    TranScan c:\Files\Area0001\*.ZIP -Carj -D -M5

        -S                        SUB-DIRECTORY SCAN        NO in SCANFILE.BAT
                  You can now TranScan all the Sub-Directories below the
                  current director, or the entire disk if you are in the root
                  directory.  (i.e., to convert *.ZIP files on the whole drive
                  to *.ARJ for about 60 minutes a night until done try the
                  example below)
                   
                  EXAMPLE: cd\
                           TramScam *.ZIP -S -Carj -M60

        -X                   EXCLUDE RECOMPRESSING SWITCH   NO in SCANFILE.BAT
                  This switch tells TranScan to NOT ReCompress a file that is
                  already compressed with the method of choice. (Note: If you
                  use -D and -X together ONLY files that were ReCompressed
                  using a different Compression method will appear in the
                  TRANSCAN.DID list.  Also, if you use the -X switch files to
                  be deleted that are listed in TRANSCAN.DEL will not be
                  deleted in files not ReCompressed.)
                   
                  EXAMPLE: TranScan -F -CARJ -X

        -Z<filePathAndName>    COMMENT FILE PATH & NAME    YES in SCANFILE.BAT
                  If this switch is not used TranScan will add the contents of
                  TRANSCAN.CMT, located in the same directory as TRANSCAN.EXE,
                  as the ZIP or ARJ comment if it exists.  With this switch




         



        2/25/92                     TRANSCAN v2.30                      Page 7

                  you can specify any other comment file.
                   
                  EXAMPLE: TranScan %1 -Zc:\wc30\BBS.ADD 

        -!                   AUTHENTICITY VERIFICATION ON   NO in SCANFILE.BAT
                  If you have a REGISTERED version of PKZIP you can include
                  this switch on the command line.  This switches Authenticity
                  Verification ON while PKZIP compresses your files.  See the
                  manual that comes with PKZIP for more information.
                   
                  EXAMPLE: TranScan -F -CZIP -!

        -T<K|C|Y|O><W>            TIME STAMP SWITCH        YES in SCANFILE.BAT
                  This TimeStamp switch instructs TranScan on how to date the
                  finished file after processing.
                  -TK for Keep Original File Date.
                  -TC for Current System Date.
                  -TY for Date of Youngest File in the file.
                  -TO for Date of Oldest File in the file.
                   
                  EXAMPLE: TranScan %1 -TY
                     or    TranScan -F -CARJ -G -TY
                   
                  Wildcat 3+ SysOps:
                  Put a "W" behind any one of these date switches (-TKW, -TCW,
                  -TYW, OR -TOW) if you want the date changed in the Wildcat
                  3+ Database.  (NOTE: I would consider this carefully because
                  adding the "W" basically eliminates much of the
                  functionality of the "[N]ew Files Since" command on the
                  Wildcat File Menu.)
                   
                  EXAMPLE: TranScan %1 -TYW
                     or    TranScan -F -CARJ -G -TYW 

        -N                        NEEDED FILE CHECK         NO in SCANFILE.BAT
                  This displays the Programs NEEDED by TranScan for full
                  operation and it checks those programs it has found in your
                  PATH.  This switch must not be used with any other switches.

        -?                           HELP SCREEN            NO in SCANFILE.BAT
                  This switch displays a simple Help Screen.  This switch must
                  not be used with any other switches.

        3.0 USE [esc] TO ABORT PROCESSING!
        ----------------------------------

        To abort  processing between  files just  pres [esc].   TranScan  will
        finish working with the file it  is processing right now, but it  will
        stop before proceeding to the next file.  TranScan will also write  an
        entry to the log reminding you that you Aborted Processing.








         



        2/25/92                     TRANSCAN v2.30                      Page 8

        4.0 WHAT HAPPENS WHEN A VIRUS IS DETECTED? 
        ------------------------------------------ 

        TranScan does several things when it detects a Virus using ViruScan by
        McFee & Associates. 

             1.   It rings your console bell several times.

             2.   It writes *** VIRUS  DETECTED *** to  your screen, your  on-
                  line caller's screen, and your TranScan.Log file. 

             3.   It determines what kind of virus was detected as reported by
                  ViruScan and  reports  this  to your  screen,  your  on-line
                  caller's screen, and your TranScan.Log file. 

             4.   It Toggles the  "Scan Failed"  switch to ON  in the  Wildcat
                  File Database (ALLFILES.DAT). 

             5.   It creates SCANFILE.BAD  in your Node  Work Directory  (e.g.
                  c:\wc30\wcwork\node1) so that  Wildcat is  alerted that  the
                  Scan Failed. 

             6.   TranScan renames the file containing  the virus to *.BAD  so
                  that there is no possibility  that a user will download  the
                  file or that you  will UnCompress it  and release the  Virus
                  accidentally. 

        5.0 EXIT ERRORLEVELS: 
        --------------------- 

                  10   DOS ERROR! Check Log File for Explanation!

                  5    Error on Command Line!

                  4    Error Detected during Compression!

                  3    Error Detected during ViruScan!

                  2    Error Detected during UnCompression!

                  1    VIRUS DETECTED or FILE AGE > MAX AGE!

                  0    Program Terminated Normally!

        Wildcat SysOps Please Note:

        You DO NOT  need to test  for an ERRORLEVEL  in your SCANFILE.BAT.  If
        VIRUS was detected,  or the  File is older  than MaxAge,  or an  Error
        occurred during processing TranScan sets  the SCAN FAILED flag in  the
        Wildcat Database  automatically and  also writes  TRANSCAN.BAD in  the
        "WILDCAT! Node Work Directory" (e.g. C:\WC30\WCWORK\NODE1 ).







         



        2/25/92                     TRANSCAN v2.30                      Page 9

        6.0 COPYRIGHT: 
        ------------- 

        This program is distributed as SHAREWARE.  Under this concept you  may
        use the SHAREWARE  (UnRegistered) version for  a reasonable period  of
        time, which I consider  to be 30 days,  after which you must  register
        your copy  or  discontinue usage  all  together.   The  Trial  Version
        contains all the features described in these documents including COM &
        NETWORK support.    Please  support the  SHAREWARE  concept.    PLEASE
        REGISTER! 

        7.0 WARRANTY: 
        ------------ 

        Users of TranScan must accept this disclaimer of warranty:  

             "TranScan is  supplied  as is.    The author  disclaims  all
             warranties,  expressed   or  implied,   including,   without
             limitation, the warranties of merchantability and of fitness
             for any  purpose.    The author  assumes  no  liability  for
             damages, direct or consequential, which may result from  the
             use of TranScan." 

        8.0 REGISTRATION: 
        ---------------- 

        With registration you will receive access to Download or File  Request
        any further updates from THE COMPUTER POST at no extra cost.  Cost  to
        register this program is only $15  for TranScan with COM routines  and
        Network Support; $10 for TranScan with  COM routines only; and $5  for
        TranScan Standard. 

        European Customers may purchase TranScan  from Gerald Janes at  Hawk's
        Castle BBS in Berkshire, UK.  See the registration form at the end  of
        this document for more information. 

        9.0 WHAT ABOUT DESC.SDI & FILE_ID.DIZ FILES?
        -------------------------------------------- 

        TranScan checks for the existence of DESC.SDI or FILE_ID.DIZ
        description files inside uploaded compressed files.  If it detects one
        of these files it reads the first 60 characters of the first line of
        the file as the File Description and updates the Wildcat Database
        Description.  It also selects the first six different words in the
        description as the KEY WORDS.  This is important to help with KEY WORD
        searches for files.   

        DESC.SDI and FILE_ID.DIZ files are becoming the standard for
        description files.  Please do not use this file for BBS advertising.   

        TranScan will default to the description in these files overwriting
        any descriptions supplied by the Uploader.  Now with TranScan
        installed on your BBS you may tell your uploaders to create the





         



        2/25/92                     TRANSCAN v2.30                     Page 10

        description file and upload files to your BBS skipping the Wildcat
        description prompts. 

        You can add the DESC.SDI and FILE_ID.DIZ filenames to your
        TRANSCAN.DEL file and TranScan will import the description but delete
        these files before ReCompressing the file.  I would discourage you
        from doing this, but it is available if you so choose. 

        (NOTE:  At this time TranScan does not compare the key words selected
        with the words in your BADKEYS.LST file.  This will be added in a
        future version!)
         
        10.0 DISTRIBUTION & DISTRIBUTORS: 
        ------------------------------- 

        You  are  free,  in  fact  encouraged,  to  distribute  the  SHAREWARE
        (UnRegistered) version  of this  program in  the original  archive  in
        absolute original unmodified form. 

        The following SysOps have agreed to serve as Distributors for
        TranScan: 

          UNITED KINGDOM
             Gerald Janes at Hawk's Castle BBS (UK sales point for Wildcat!)
             BBS: +44 344 411621 (V32bis)  FIDO: 2:254/169

          LA PUENTE, CALIFORNIA
             Rick Emmick at Learning Experience BBS
             BBS: 818-913-6843             FIDO: 1:102/592

          PALENTINE, ILLINOIS
             Bill Masella at The File Depot BBS
             BBS: 708-202-1516 

          METHUEN, MASSACHUSETS
             Brian Morison at Midnight Shift BBS
             BBS: 508-688-5209             FIDO: 1:324/280

          PEMBROKE, NEW HAMPSHIRE
             Mark Tetrault at Pembroke Connection BBS
             BBS: 603-485-8549             FIDO: 1:132/169

          CHILLICOTHE, OHIO
             Jerry Arnold at South of the Bauder BBS
             BBS: 614-773-2423             FIDO: 1:2220/70

          CHESAPEAKE, VIRGINIA
             Richard Hoover at The Twilight Hour BBS
             BBS: 804-548-1102 

        Anyone distributing TranScan for any  kind of remuneration must  first
        contact Craig Dunstan at the address below for authorization.  This is
        also important so that the distributor can be kept up-to-date with the
        latest version of TranScan. 




         



        2/25/92                     TRANSCAN v2.30                     Page 11


        11.0 TECHNICAL SUPPORT: 
        ---------------------- 

        The author is available to provide free technical support if you  have
        problems with  or questions  about TranScan.   You  may contact  Craig
        Dunstan in any of the following ways: 

        PHONE:         507-345-3061 (leave a mssg.)

        U.S. MAIL:     Craig Dunstan
                       The Computer Post BBS
                       235 Jaycee Ct. #104
                       Mankato, MN. 56001

        BBS:           THE COMPUTER POST BBS (507) 345-3075 (24/hrs).

        NETMAIL:       Send Netmail Messages to FIDO 1:14/779.

        COMPUSERVE:    Address Messages to Craig Dunstan at 70713,671.

               BE SURE TO INCLUDE THE VERSION NUMBER IN YOUR MESSAGES! 




































         



        2/25/92                     TRANSCAN v2.30                     Page 12

        12.0 ACKNOWLEDGEMENTS: 
        --------------------- 

             o    Wildcat (tm) (c) Mustang Software, Bakersfield, CA.

             o    These programs  were written  using  Turbo Pascal  5.5  from
                  Boreland International, Scotts Valley, CA. 

             o    These programs were written using B-Tree Filer and  AsyncPro
                  from Turbo Power Software, (c) 1989-1991, Scotts Valley, CA. 

             o    ViruScan (c) 1989-1991 by McAfee & Associates.

             o    ZC (c) by Jeff Garzik.

             o    PkPak, PkUnPak, PkZip (tm),  and PkUnZip (tm) (c)  1986-1989
                  by Phillip W. Katz, PKWARE Inc. 

             o    LHa, LHarc and LHice (c) 1988-1989 by Haruyasu Yoshisaki.

             o    Pak (c) 1988-1989 by NoGate Consulting.

             o    Zoo (c) 1988 by Rahul Dhesi.

             o    Arj (c) 1990-1991 by Robert K. Jung.

             o    Hyper (c) 1989-1990 by P. Sawatzki & K.P. Nischke.

             o    DWC (c) 1986-1990 by Dean W. Cooper.

             o    GIFLite (c) 1991 by Tsung Hu.



























         



        2/25/92                     TRANSCAN v2.30                     Page 13

        13.0 BETA TEST TEAM: 
        ------------------- 

        How do you  adequately thank  all the  people that  contribute to  the
        development of  a project  like TranScan?   Many  people have  offered
        their ideas and suggestions, their  criticism and encouragement.   The
        Beta Testers have  helped me  through the  tough times  when I  didn't
        think I  would ever  fix  the broken  stuff.   I'm  sure I  will  miss
        someone, but the following have definitely made their contribution  to
        TranScan.  Please visit their BBS and tell them Thanks for me. 

        SySop            BBS Name               BBS Phone      Fido Address
        ---------------- -------------------    ------------   ---------------
        Jerry Arnold     South of the Bauder    614-773-2423   1:2220/70
        Les Campbell     RedEye                 403-381-8674   1:358/15
        Steve Carcas                            249-891-503    2:225/301
        Robert Carlson   Starview Connection    612-588-3301   1:282/28
        Jim Charette                                           
        Dean Cordle      Inland Waves           804-468-9333   
        David Costelloe  Get Smart              416-338-5891   
        Dale Crosbie     The Wild-Card          619-565-0113   
        Danny Davis      The Light House BBS    209-442-8329   1:205/75
        Hal Davis        Hal's Haven            503-297-2914   1:105/88
        Chris Dennis     Current Event          215-245-4316   
        Ken Dozotell     Nite-Air BBS           315-339-8831   1:260/503
        William Edsall   Nascent Telecomm       219-745-1416   
        Rick Emmick      Learning Experience    818-913-6843   1:102/592
        Doug Fischer     Fischer's Software     805-722-4261 
        Adam Getchell    The Rocket Express     805-275-5873   
        Vernon Gilmore   The Funny Farm         619-449-8933   1:202/336
        Richard Hoover   The Twilight Hour      804-548-1102   
        Jerry Houston    Programmer's Resource  206-823-2831   
        Marc Hufnagel    HDC!                   618-684-3990   
        Gerald Janes     Hawk's Castle          034-441-1621   2:254/169
        Ed Jeffers       The Board              818-366-8874   
        David Katz       Microware Tech         503-526-2667   
        David Kaufman    Brooklyn Broadcasting  813-375-6569   
        Manfred Luft     QEdit Support Germany  497-615-8052   
        Gregg Maroney    Mo's Back Door         406-756-8296 
        Bill Masella     The File Depot         708-202-1516   
        James Minton     The Outer Limits       205-985-1725   1:3602/12
        Brian Morison    Midnight Shift         508-688-5209   1:324/280
        Roger Prokic     The Space Academy BBS  407-799-3267   1:374/40
        Richard Reed     The Drak Empire BBS    804-545-7682   1:271/45
        Carl Ricketts    The Index Linked BBS   44-0227-770403 2:440/15
        Frank Self       The Catfish Depot      409-385-7515   
        Kevin Sonney     DaVinci Tech Support   919-881-4342   1:151/110
        Chris Stewart    Inland Waves BBS       804-468-9333   1:275/18
        Mike Surfer      Bit's n Pc's           703-373-0738   
        Mark Tetrault    Pembroke Connection    603-485-8549   1:132/169
        Chris Williams   FogBound               805-929-2201 







         



        2/25/92                     TRANSCAN v2.30                     Page 14

        14.0 ERROR CODES OF EXTERNAL PROGRAMS 
        ------------------------------------- 

        TranScan  monitors  the  ErrorLevel  Code  returned  by  all  external
        programs called  and records  these codes  in the  TranScan.Log.   The
        following is  an  explanation of  each  of the  ErrorLevels  for  each
        external program supported: 

        ARJ.EXE (Arj200.exe): 
         
            0     Success
            1     Warning (specified  file  to add  to  archive not  found  or
                  specified file to list, extract, etc., not found)
            2     Fatal Error
            3     CRC error (header or file CRC error)
            4     ARJ-SECURITY error  or  attempt  to  update  an  ARJ-SECURED
                  archive
            5     Disk full or write error
            6     Can't open archive or file
            7     simple user error (bad parameters)
            8     not enough memory
         
        HYPER.EXE (Hyper25.exe):
         
            0     Normal Exit
            1     Nothing to do
            2     Archive Error
            3     Compression Error
            4     Memory Error
            5     CheckSum Error
           14     Disk Full
           98     Error Creating Archive
          101     Input Error
          102     Output Error
          255     Control-C pressed
         
        LHARC (Lh113c.exe):
         
            0     Normally finished.
            1     Process finished with nonexistent file names ignored  during
                  archiving or CRC error occurred during un-archiving.
            2     Process terminated  by fatal  error; no  archive created  or
                  files moved.
            3     Unable to write temporary files into the archive.  Work file
                  renamed to 'LHARC.)2('  and original archive  deleted.   Try
                  renaming LHARC.)2)  as your  archive, although  it might  be
                  damaged.
         
        PAK (Pak210.exe):
         
            0     No Error
            1     CRC error in file or file missing
            2     Out of memory
            7     Disk error




         



        2/25/92                     TRANSCAN v2.30                     Page 15

         
         
        PKPAK & PKUNPAK (Pk361.exe) and PKXARC (Pkxarc.exe): 
         
            0     No Error
            1     Bad CRC, file is not an archive, unknown compression method,
                  can't create a file,  squeeze table is  invalid or no  files
                  found to extract.
            2     Out of memory
            3     No archives found to extract
            4     Can't open archive file
            5     Read error on archive
            6     Internal table overflow
            7     Disk full
         
        PKZIP (Pkz110.exe)
         
            0     No Error
            1     Bad file name or file specification
          2,3     Error in ZIP file
         4-11     Insufficient Memory
           12     No files were found to add to the ZIP file, or no files were
                  specified for deletion
           13     File not found
           14     Disk full
           15     ZIP file is read-only and can not be modified
           16     Bad or illegal parameters specified
           17     Too many files
         
        PKUNZIP (Pkz110.exe):
         
            0     No error
            1     Warning error (such as failed CRC check)
          2,3     Error in ZIP file
          4-8     Insufficient Memory
            9     File not found. No ZIP files found.
           10     Bad or illegal parameters specified.
           11     No files found to extract/view etc.
           50     Disk full
           51     Unexpected EOF in ZIP file
         
        SCAN.EXE (Scanv80.zip):
         
            0     No viruses found
            1     One or more viruses found
            2     Abnormal termination (program error)
         
                  I do  not  have  the  ErrorLevel  codes  for  LHA212.EXE  or
                  ZOO200.EXE.  If anyone has a list of these for me I will  be
                  sure to include them in the next revision of these DOCs.
         







         



        2/25/92                     TRANSCAN v2.30                     Page 16

        15.0 COMMAND LINE OPTIONS USED IN EXTERNAL PROGRAMS
        --------------------------------------------------- 

        Several people  have  asked  what  command line  options  I  have  set
        TranScan to use for the over  15 external programs it calls from  time
        to time.  I thought  that to be a fair  question so I will attempt  to
        answer it here: 

        For Scanning:
        ------------
        SCAN.EXE <filePath or fileName> /NOMEM /NOPAUSE /REPORT
        <reportFileName> 

        For GIFLite:
        -----------
        GIFLITE.EXE -9 -b -t <fileName> 

        For TDCheck:
        -----------
        TDCHECK.EXE <fileName> 

        For Adding Comments:
        -------------------
        ZC.EXE <fileName> <commentFileName>
        ARJ.EXE c <fileName> -Z<commentFileName> 

        For Extracting Files:
        --------------------
        PKUNPAK.EXE <fileName> <tempPath>
        ARJ.EXE e <fileName> <tempPath>
        DWC.EXE e <fileName> <tempPath>
        HYPER.EXE -x <fileName> <tempPath>
        ICE.EXE e <fileName> <tempPath>
        LHA.EXE x <fileName> <tempPath>
        PAK.EXE e <fileName> <tempPath>
        PKUNZIP.EXE -o <fileName> <tempPath>
        ZOO.EXE cd\<tempPath
                ZOO.EXE e <fileName>
                cd\<originalPath> 

        For Compressing Files:
        ---------------------
        PKPAK.EXE -a <newFileName> <tempPath>
        ARJ.EXE -a -e -jm <newFileName> <tempPath>
        DWC.EXE az <newFileName> <tempPath>
        HYPER.EXE -a <newFileName> <tempPath>
        ICE.EXE a <newFileName> <tempPath>
        LHA.EXE a <newFileName> <tempPath>
        PAK.EXE a <newFileName> <tempPath>
        PKZIP.EXE -a -ex <newFileName> <tempPath> ( add -! for Auth.Verif.)
        ZOO.EXE a <newFileName> <tempPath>